#
# spec file for package ibsim
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define git_ver .0.aa3c4458c488

Summary:        InfiniBand fabric simulator for management
License:        BSD-2-Clause OR GPL-2.0-only
Group:          Productivity/Networking/Diagnostic

Name:           ibsim
Version:        0.8
Release:        lp152.1.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         ibsim-%{version}%{git_ver}.tar.gz
Patch1:         ibsim-fix_type_punning.patch
Patch2:         umad2sim-Do-not-use-umad.h-deprecated-functions.patch
Patch3:         umad2sim-define-UMAD_DEV_DIR-if-not-set.patch
Url:            https://github.com/linux-rdma/ibsim
BuildRequires:  infiniband-diags-devel
BuildRequires:  libibumad-devel
BuildRequires:  make

%description
ibsim provides simulation of infiniband fabric for using with OFA
OpenSM, diagnostic and management tools.


%prep
%setup -q -n  %{name}-%{version}%{git_ver}
%patch1
%patch2
%patch3

%build
export CFLAGS="${CFLAGS:-%{optflags}}"
export LDFLAGS="${LDFLAGS:-%{optflags}}"
make prefix=%_prefix libpath=%_libdir binpath=%_bindir %{?_smp_mflags}

%install
export CFLAGS="${CFLAGS:-%{optflags}}"
export LDFLAGS="${LDFLAGS:-%{optflags}}"
make DESTDIR=%{buildroot} prefix=%_prefix libpath=%_libdir binpath=%_bindir install

%files
%defattr(-,root,root)
%dir %{_libdir}/umad2sim
%{_libdir}/umad2sim/libumad2sim*.so*
%{_bindir}/ibsim
%doc README COPYING TODO net-examples scripts

%changelog
* Fri Oct 11 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Add patches to fix support with rdma-core >= 25
  - umad2sim-Do-not-use-umad.h-deprecated-functions.patch
  - umad2sim-define-UMAD_DEV_DIR-if-not-set.patch
* Thu Apr 18 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Remove unneeded build dependencies
* Wed Apr 17 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 0.8
  - Extended speed support including HDR and FDR10
  - 2x link support
  - Link speed, espeed, and width change support
  - Support for PortXmitWait field in PortCounters
  - Minor changes/bug fixes
* Fri Jun 15 2018 nmoreychaisemartin@suse.com
- Update Source and URL as ibsim was moved to GitHub
- Add a _service file to be able to auto-fetch from github
* Fri Jun 23 2017 nmoreychaisemartin@suse.com
- Replace dependency from libibmad-devel to infiniband-diags-devel
* Thu Jun  8 2017 nmoreychaisemartin@suse.com
- Update to version 0.7
  * PerformanceSet handling for enhanced switch port 0
  * Fix incorrectly updated port counters in pc_updated()
  * Invalidate PerformanceSet commands with no port number
  * Fix parsing of port number in PerformanceSet command
  * Allocate MFT according to number of switch ports
* Wed Mar 29 2017 pth@suse.de
- Make dependencies on libs now coming from rdma-core versioned.
* Thu Mar 10 2016 pth@suse.de
- Update to latest git version 0.6-gitf9acb41 (bsc#970668):
  * sim_cmd.c: PerformanceSet handling for enhanced switch port 0
    Setting the perf counters of the port 0 is only allowed when
    the node is a switch with an enhanced port 0
  * sim_mad.c: Fix incorrectly updated port counters in pc_updated()
    When the IB packet gets out of the source port,
    the Xmit fields of the source port are now updated.
  * sim_cmd.c: Invalidate PerformanceSet commands with no port number
    Syntax: sim> PerformanceSet "nodeid"[port] [attribute].[field]=[value]
  * sim_cmd.c: Fix parsing of port number in PerformanceSet command
    Syntax: sim> PerformanceSet "nodeid"[port] [attribute].[field]=[value]
  * ibsim: Allocate MFT according to number of switch ports
    Calculate number of port masks according to number of switch ports
    and allocate MFT accordingly
- Include ChangeLog generated from git log.
- Add ibsim-fix_type_punning.patch to replace type-punning by
  memcpy.
* Wed Jun 25 2014 pth@suse.de
- Don't use a full source URL as a package with the current version
  isn't anymore available standalone.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Fri Feb 14 2014 pth@suse.de
- Remove an empty macro which the rpm parser won't grok.
* Thu Feb 13 2014 pth@suse.de
- Update to 0.6 for fate#315488. No Changelog in package.
- Use full source URI and don't recompress the tarball.
* Fri Jan 24 2014 pth@suse.de
- Update to OFED 3.12 daily
* Tue May  8 2012 pth@suse.de
- BuildRequire automake, autoconf and libtool.
* Thu Feb  3 2011 ro@suse.de
- correct buildrequirs to libibmad-devel
* Fri Oct 29 2010 stefan.fent@novell.com
- correct requires to libibumad-devel
* Wed Oct 27 2010 jjolly@novell.com
- Updated to v0.5-0.1.g327c3d8 from OFED 1.5.2
* Thu Dec 11 2008 jjolly@suse.de
- Updated to v0.5 from OFED 1.4 GA
  - No changelog provided
* Thu Nov 13 2008 ro@suse.de
- excludearch s390
* Mon Oct 27 2008 jjolly@suse.de
- Updated to version from OFED 1.4 rc3
- bzipped source tarball
* Wed Sep 10 2008 jjolly@suse.de
- Recreated the package for SLES11
